<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>DisplayDistanceAngle</name>
    <message>
        <location filename="../DisplayDistanceAngleInit.js" line="+2"/>
        <source>Display &amp;Distance/Angle</source>
        <translation>Zobrazit &amp;Vzdálenost/Úhel</translation>
    </message>
</context>
</TS>
